==> aliyun-python-sdk-kms-2.13.0.tar.gz: aliyun-python-sdk-kms-2.13.0/aliyunsdkkms/request/v20160120/CertificatePrivateKeyDecryptRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkkms.endpoint import endpoint_data

class CertificatePrivateKeyDecryptRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Kms', '2016-01-20', 'CertificatePrivateKeyDecrypt','kms-service')
		self.set_protocol_type('https')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_CertificateId(self):
		return self.get_query_params().get('CertificateId')

	def set_CertificateId(self,CertificateId):
		self.add_query_param('CertificateId',CertificateId)

	def get_Algorithm(self):
		return self.get_query_params().get('Algorithm')

	def set_Algorithm(self,Algorithm):
		self.add_query_param('Algorithm',Algorithm)

	def get_CiphertextBlob(self):
		return self.get_query_params().get('CiphertextBlob')

	def set_CiphertextBlob(self,CiphertextBlob):
		self.add_query_param('CiphertextBlob',CiphertextBlob)

==> aliyun-python-sdk-kms-2.15.0.tar.gz: aliyun-python-sdk-kms-2.15.0/aliyunsdkkms/request/v20160120/CertificatePrivateKeyDecryptRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkkms.endpoint import endpoint_data

class CertificatePrivateKeyDecryptRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Kms', '2016-01-20', 'CertificatePrivateKeyDecrypt','kms')
		self.set_protocol_type('https')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_CertificateId(self):
		return self.get_query_params().get('CertificateId')

	def set_CertificateId(self,CertificateId):
		self.add_query_param('CertificateId',CertificateId)

	def get_Algorithm(self):
		return self.get_query_params().get('Algorithm')

	def set_Algorithm(self,Algorithm):
		self.add_query_param('Algorithm',Algorithm)

	def get_CiphertextBlob(self):
		return self.get_query_params().get('CiphertextBlob')

	def set_CiphertextBlob(self,CiphertextBlob):
		self.add_query_param('CiphertextBlob',CiphertextBlob)
